@@ -396,4 +396,4 @@ class EthBridgeTestCase(unittest.TestCase):
 if __name__ == "__main__":
     from test_manifest import manifest
 
-    unittest.main(exit=False)
+    unittest.main(exit=True)
