@@ -3,7 +3,7 @@ import os
 import sys
 import logging
 import unittest
-
+from functools import partial
 from decimal import Decimal
 from enum import Enum
 from typing import Dict, List, Tuple, Optional, Any
@@ -23,6 +23,7 @@ from hmt_escrow.eth_bridge import (
     get_w3,
     handle_transaction,
 )
+from hmt_escrow import utils
 from hmt_escrow.storage import download, upload
 from basemodels import Manifest
 
@@ -351,7 +352,14 @@ class Job:
         self.manifest_hash = hash_
         return self.status() == Status.Launched and self.balance() == 0
 
-    def setup(self, gas: int = GAS_LIMIT) -> bool:
+    def setup(
+        self,
+        gas: int = GAS_LIMIT,
+        blocking: bool = False,
+        retries: int = 3,
+        delay: int = 5,
+        backoff: int = 2,
+    ) -> bool:
         """Sets the escrow contract to be ready to receive answers from the Recording Oracle.
         The contract needs to be deployed and funded first.
 
@@ -450,6 +458,11 @@ class Job:
                 f"{txn_event} failed with main credentials: {self.gas_payer}, {self.gas_payer_priv} due to {e}. Using secondary ones..."
             )
 
+        if not contract_is_setup and blocking:
+            fn = partial(handle_transaction, *func_args, **txn_info)
+            fn.__name__ = f"Job.setup.{handle_transaction.__name__}"  # type:ignore
+            contract_is_setup = utils.with_retry(fn, retries, delay, backoff)
+
         if not contract_is_setup:
             contract_is_setup = self._raffle_txn(
                 self.multi_credentials, txn_func, func_args, txn_event
@@ -620,9 +633,9 @@ class Job:
         """Kills the contract and returns the HMT back to the gas payer.
         The contract cannot be aborted if the contract is in Partial, Paid or Complete state.
 
-        Returns:        
+        Returns:
             bool: returns True if contract has been destroyed successfully.
-        
+
         >>> credentials = {
         ... 	"gas_payer": "0x1413862C2B7054CDbfdc181B83962CB0FC11fD92",
         ... 	"gas_payer_priv": "28e516f1e2f99e96a48a23cea1f94ee5f073403a1c68e818263f0eb898f1c8e5"
@@ -1442,7 +1455,7 @@ class Job:
             txn_args (List): the arguments the transaction takes.
             txn_event (str): the transaction event that will be performed.
             gas (int): maximum amount of gas the caller is ready to pay.
-        
+
         Returns:
             bool: returns True if the given transaction succeeds.
 
@@ -1726,4 +1739,4 @@ class JobTestCase(unittest.TestCase):
 if __name__ == "__main__":
     from test_manifest import manifest
 
-    unittest.main(exit=False)
+    unittest.main(exit=True)
