@@ -1,16 +1,15 @@
-import os
-import logging
 import codecs
 import hashlib
 import json
+import logging
+import os
 import unittest
-
 from typing import Dict, Tuple
-from eth_keys import keys
-from p2p import ecies
 
 import boto3
-from botocore.client import Config
+from eth_keys import keys
+
+import crypto
 
 SHARED_MAC_DATA = os.getenv(
     "SHARED_MAC", b"9da0d3721774843193737244a0f3355191f66ff7321e83eae83f7f746eb34350"
@@ -111,7 +110,7 @@ def upload(msg: Dict, public_key: bytes) -> Tuple[str, str]:
     >>> manifest_dict = download(manifest_url, job.gas_payer_priv)
     >>> manifest_dict == job.serialized_manifest
     True
-    
+
     >>> job = Job(credentials=credentials, escrow_manifest=manifest)
     >>> (hash_, manifest_url) = upload(job.serialized_manifest, pub_key)
     >>> manifest_url.startswith('s3')
@@ -162,7 +161,7 @@ def _decrypt(private_key: bytes, msg: bytes) -> str:
     >>> false_pub_key = b"74c81fe41b30f741b31185052664a10c3256e2f08bcfb20c8f54e733bef58972adcf84e4f5d70a979681fd39d7f7847d2c0d3b5d4aead806c4fec4d8534be114"
     >>> _decrypt(priv_key, _encrypt(false_pub_key, msg)) == msg
     Traceback (most recent call last):
-    p2p.exceptions.DecryptionError: Failed to verify tag
+    crypto.DecryptionError: Failed to verify tag
 
     Args:
         private_key (bytes): The private_key to decrypt the message with.
@@ -173,7 +172,7 @@ def _decrypt(private_key: bytes, msg: bytes) -> str:
 
     """
     priv_key = keys.PrivateKey(codecs.decode(private_key, "hex"))
-    e = ecies.decrypt(msg, priv_key, shared_mac_data=SHARED_MAC_DATA)
+    e = crypto.decrypt(msg, priv_key, shared_mac_data=SHARED_MAC_DATA)
     return e.decode("utf-8")
 
 
@@ -197,7 +196,7 @@ def _encrypt(public_key: bytes, msg: str) -> bytes:
     """
     pub_key = keys.PublicKey(codecs.decode(public_key, "hex"))
     msg_bytes = msg.encode("utf-8")
-    return ecies.encrypt(msg_bytes, pub_key, shared_mac_data=SHARED_MAC_DATA)
+    return crypto.encrypt(msg_bytes, pub_key, shared_mac_data=SHARED_MAC_DATA)
 
 
 class StorageTest(unittest.TestCase):
@@ -235,15 +234,13 @@ class StorageTest(unittest.TestCase):
         self.assertEqual(manifest_dict, job.serialized_manifest)
 
     def test_decrypt(self):
-        from p2p.exceptions import DecryptionError
-
         priv_key = "28e516f1e2f99e96a48a23cea1f94ee5f073403a1c68e818263f0eb898f1c8e5"
         pub_key = b"2dbc2c2c86052702e7c219339514b2e8bd4687ba1236c478ad41b43330b08488c12c8c1797aa181f3a4596a1bd8a0c18344ea44d6655f61fa73e56e743f79e0d"
         msg = "test"
         self.assertEqual(_decrypt(priv_key, _encrypt(pub_key, msg)), msg)
         # Using a wrong public key to decrypt a message results in failure.
         false_pub_key = b"74c81fe41b30f741b31185052664a10c3256e2f08bcfb20c8f54e733bef58972adcf84e4f5d70a979681fd39d7f7847d2c0d3b5d4aead806c4fec4d8534be114"
-        with self.assertRaises(DecryptionError):
+        with self.assertRaises(crypto.DecryptionError):
             _decrypt(priv_key, _encrypt(false_pub_key, msg)) == msg
 
     def test_encrypt(self):
@@ -257,4 +254,4 @@ if __name__ == "__main__":
     from test_manifest import manifest
     from job import Job
 
-    unittest.main(exit=False)
+    unittest.main(exit=True)
